You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flex.apache.org by jm...@apache.org on 2014/06/30 05:05:01 UTC

[1/2] git commit: [flex-sdk] [refs/heads/release4.13.0] - Updated MD5 for FP 14.0

Repository: flex-sdk
Updated Branches:
  refs/heads/release4.13.0 b98a03299 -> 64978e57f


Updated MD5 for FP 14.0


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/254c3e0a
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/254c3e0a
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/254c3e0a

Branch: refs/heads/release4.13.0
Commit: 254c3e0a3558242ca46ee8b7e1b7e4c65dbcb700
Parents: b98a032
Author: Justin Mclean <jm...@apache.org>
Authored: Mon Jun 30 12:52:28 2014 +1000
Committer: Justin Mclean <jm...@apache.org>
Committed: Mon Jun 30 12:52:28 2014 +1000

----------------------------------------------------------------------
 ide/checkAllPlayerGlobals.sh | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/254c3e0a/ide/checkAllPlayerGlobals.sh
----------------------------------------------------------------------
diff --git a/ide/checkAllPlayerGlobals.sh b/ide/checkAllPlayerGlobals.sh
index 646121b..6ee9624 100755
--- a/ide/checkAllPlayerGlobals.sh
+++ b/ide/checkAllPlayerGlobals.sh
@@ -122,5 +122,5 @@ downloadPlayerGlobal 11.8 35bc69eec5091f70e221b4e63b66b60f http://download.macro
 downloadPlayerGlobal 11.9 d18244c3c00c61a41f2d4d791d09fedb http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_9.swc
 downloadPlayerGlobal 12.0 4db4e934f39f774ba68fcd9a79654971 http://download.macromedia.com/get/flashplayer/updaters/12/playerglobal12_0.swc
 downloadPlayerGlobal 13.0 7f9bfe038f00e97bc44abf52bb5b1260 http://download.macromedia.com/get/flashplayer/updaters/12/playerglobal13_0.swc
-downloadPlayerGlobal 14.0 2465d2fcf0d985ed10231b43f61c3024 http://download.macromedia.com/get/flashplayer/updaters/12/playerglobal14_0.swc
+downloadPlayerGlobal 14.0 21fe2130f44ba535a6d250e65e6f260e  http://download.macromedia.com/get/flashplayer/updaters/12/playerglobal14_0.swc
 


[2/2] git commit: [flex-sdk] [refs/heads/release4.13.0] - Updated to use FP14. Fixed minor formatting issues.

Posted by jm...@apache.org.
Updated to use FP14. Fixed minor formatting issues.


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/64978e57
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/64978e57
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/64978e57

Branch: refs/heads/release4.13.0
Commit: 64978e57f5ee2198963a667048f1dd8f13270640
Parents: 254c3e0
Author: Justin Mclean <jm...@apache.org>
Authored: Mon Jun 30 12:52:55 2014 +1000
Committer: Justin Mclean <jm...@apache.org>
Committed: Mon Jun 30 12:52:55 2014 +1000

----------------------------------------------------------------------
 ide/flashbuilder/makeApacheFlexForIDE.sh | 25 +++++++++++++------------
 1 file changed, 13 insertions(+), 12 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/64978e57/ide/flashbuilder/makeApacheFlexForIDE.sh
----------------------------------------------------------------------
diff --git a/ide/flashbuilder/makeApacheFlexForIDE.sh b/ide/flashbuilder/makeApacheFlexForIDE.sh
index 1ae9e5f..fc34d52 100755
--- a/ide/flashbuilder/makeApacheFlexForIDE.sh
+++ b/ide/flashbuilder/makeApacheFlexForIDE.sh
@@ -21,13 +21,14 @@
 
 # This script should be used to create an Apache Flex SDK that has the
 # directory structure that the Adobe Flash Builder IDE expects.  If this is a
-# source package, you must build the binaries and the RSLs first.  See the README at the 
-# root for instructions.
+# source package, you must build the binaries and the RSLs first.
+#  See the README at the root for instructions.
 #
 # The Adobe AIR SDK and the Adobe Flash Player playerglobal.swc are integrated
-# into the new directory structure.  The paths in the framework configuration files are 
-# modified to reflect this.  The AIR_HOME and PLAYERGLOBAL_HOME environment variables are 
-# not required because the locations of these pieces are known.
+# into the new directory structure.  The paths in the framework configuration
+# files are modified to reflect this.  The AIR_HOME and PLAYERGLOBAL_HOME
+# environment variables are not required because the locations of these pieces
+# are known.
 #
 # Usage: makeApacheFlexForIDE [new directory to build integrated SDK]
 #
@@ -37,12 +38,12 @@
 # Apache Flex binary distribution
 APACHE_FLEX_BIN_DIR="$( cd $( dirname -- "$0" ) > /dev/null ; pwd )"/../..
 
-# Adobe AIR SDK Version 13.0
-ADOBE_AIR_SDK_MAC_URL=http://airdownload.adobe.com/air/mac/download/13.0/AdobeAIRSDK.tbz2
+# Adobe AIR SDK Version 14.0
+ADOBE_AIR_SDK_MAC_URL=http://airdownload.adobe.com/air/mac/download/14.0/AdobeAIRSDK.tbz2
 
 # Adobe Flash Player Version 11.1
 ADOBE_FLASHPLAYER_GLOBALPLAYER_11_1_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal11_1.swc
-ADOBE_FLASHPLAYER_GLOBALPLAYER_12_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/12/playerglobal12_0.swc
+ADOBE_FLASHPLAYER_GLOBALPLAYER_14_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/14/playerglobal14_0.swc
 
 # Adobe Flex SDK v4.6
 ADOBE_FLEX_SDK_URL=http://fpdownload.adobe.com/pub/flex/sdk/builds/flex4.6/flex_sdk_4.6.0.23201B.zip
@@ -103,10 +104,10 @@ echo "Downloading Adobe Flash Player playerglobal.swc from $ADOBE_FLASHPLAYER_GL
 mkdir -p "$FLEX_HOME/frameworks/libs/player/11.1"
 curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_11_1_SWC_URL" --output "$FLEX_HOME/frameworks/libs/player/11.1/playerglobal.swc"
 
-# download 11.9 playerglobal.swc
-echo "Downloading Adobe Flash Player playerglobal.swc from $ADOBE_FLASHPLAYER_GLOBALPLAYER_13_0_SWC_URL"
-mkdir -p "$FLEX_HOME/frameworks/libs/player/13.0"
-curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_13_0_SWC_URL" --output "$FLEX_HOME/frameworks/libs/player/13.0/playerglobal.swc"
+# download 14 playerglobal.swc
+echo "Downloading Adobe Flash Player playerglobal.swc from $ADOBE_FLASHPLAYER_GLOBALPLAYER_14_0_SWC_URL"
+mkdir -p "$FLEX_HOME/frameworks/libs/player/14.0"
+curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_14_0_SWC_URL" --output "$FLEX_HOME/frameworks/libs/player/14.0/playerglobal.swc"
 
 # copy the config files formatted for Flash Builder to frameworks 
 echo "Installing the frameworks config files configured for use with Adobe Flash Builder"